# PhilipstvTV GUI

[![CI](https://github.com/bcyran/philipstv-gui/workflows/CI/badge.svg?event=push)](https://github.com/bcyran/philipstv/actions?query=event%3Apush+branch%3Amaster+workflow%3ACI)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pypi](https://img.shields.io/pypi/v/philipstv-gui)](https://pypi.org/project/philipstv-gui/)
[![versions](https://img.shields.io/pypi/pyversions/philipstv-gui)](https://pypi.org/project/philipstv-gui/)
[![license](https://img.shields.io/github/license/bcyran/philipstv-gui)](https://github.com/bcyran/philipstv-gui/blob/master/LICENSE)

GUI remote for Philips Android-powered TVs.

![PhilipstvTV GUI screenshots](https://github.com/bcyran/philipstv-gui/raw/master/philipstv-gui.png)

Features:
- Full remote emulation, all standard keys available.
- List available channels and change between them.
- List available applications and launch them.
- Set Ambilight colors for each TV side separately.

## Installation

### PyPI
```shell
$ pip install philipstv-gui
```

### Arch Linux
[philipstv-gui AUR package](https://aur.archlinux.org/packages/philipstv-gui) is available.

## See also
- [`philipstv`](https://github.com/bcyran/philipstv) - CLI and library for controlling Philips Android-powered TV's.
